@@ -19,7 +19,9 @@ class Bleach:
         'M',
         'mM',
         'µM',
-        'nM'
+        'nM',
+        'g/L',
+        'mg/L'
     ]
     
     output_units = [  # No mixed
@@ -27,7 +29,9 @@ class Bleach:
         'M',
         'mM',
         'µM',
-        'nM'
+        'nM',
+        'g/L',
+        'mg/L'
     ]
     
     duplicate_methods = sorted(['average', 'remove', 'keep'])
@@ -207,7 +211,7 @@ class Bleach:
             pd.DataFrame: _description_
         """
         df = df.copy()
-        col_name = f'neg_log_molar_{value_col_name}'
+        col_name = f'neg_log_molar_{value_col_name}'  # This is necessary to avoid overwriting existing column
         
         # 1. Convert to -log(M)
         if input_units == 'mixed':  # Unit column
