@@ -14,6 +14,29 @@ class UnitConverter:
     _standard_unit_col = 'standard_unit'
     _multiplier_col = 'multiplier'
     
+    # Unit groups
+    _molars = [
+        'pm',
+        'nm',
+        'um',
+        'µm',  # Both forms of micro work
+        'mm',
+        'm'
+    ]
+    
+    _g_ovr_ls = [
+        'pg/l',
+        'ng/l',
+        'ug/l',
+        'mg/l',
+        'g/l',
+        'pg/ml',
+        'ng/ml',
+        'ug/ml',
+        'mg/ml',
+        'g/ml'
+    ]
+    
     def __init__(self, values:Iterable, units:Iterable, mol_weights:Iterable) -> None:
         # Column names
         self._unit_col = 'unit'
@@ -26,27 +49,6 @@ class UnitConverter:
             self._mw_col: copy.deepcopy(mol_weights)
         })
         
-        # Unit groups
-        self.molar = [
-            'pm',
-            'nm',
-            'um',
-            'mm',
-            'm'
-        ]
-        self.g_ovr_l = [
-            'pg/l',
-            'ng/l',
-            'ug/l',
-            'mg/l',
-            'm/l',
-            'pg/ml',
-            'ng/ml',
-            'ug/ml',
-            'mg/ml',
-            'm/ml'
-        ]
-        
         self.df = UnitConverter.standardize_units(self.df, self._unit_col)
     
     @staticmethod
@@ -111,25 +113,32 @@ class UnitConverter:
             raise ValueError(f'Output units: "{output_units}" are not recognized')
         
         return df.dropna(subset=[col_name]) if drop_na_units else df
-        
+    
     @staticmethod
-    def convert(values:Iterable[float], in_unit:str, out_unit:str) -> str:
+    def convert(values:Iterable[float], in_unit:str, out_unit:str, mws:Iterable[float]=None) -> str:
         '''Simply converts from one unit to another. out_unit can be -log(M)'''
-        try:
-            if in_unit.lower() == '-log(m)':
-                molar_values = [UnitConverter.inv_neg_log(v) for v in values]
-            else:
-                molar_values = [v * UnitConverter._recognized_units[in_unit.lower()][1] for v in values]
-        except KeyError:
-            raise ValueError(f'Unit {in_unit} not recognized.')
+        if in_unit.lower() == out_unit.lower():
+            return values
+        
+        for u in [in_unit, out_unit]:
+            if u.lower() not in ['-log(m)'] + UnitConverter._molars + UnitConverter._g_ovr_ls:
+                raise ValueError(f'Unit {u} not recognized')
+            elif not mws and u.lower() in UnitConverter._g_ovr_ls:
+                raise ValueError(f'Unit {u} requires molar weights')
+        
+        if in_unit.lower() == '-log(m)':
+            molar_values = [UnitConverter.inv_neg_log(v) for v in values]
+        elif in_unit.lower() in UnitConverter._molars:
+            molar_values = [v * UnitConverter._recognized_units[in_unit.lower()][1] for v in values]
+        else:
+            molar_values = [v / mw * UnitConverter._recognized_units[in_unit.lower()][1] for v, mw in zip(values, mws)]
         
         if out_unit.lower() == '-log(m)':
             return [UnitConverter.neg_log(m) for m in molar_values]
+        elif out_unit.lower() in UnitConverter._molars:
+            return [m / UnitConverter._recognized_units[out_unit.lower()][1] for m in molar_values]
         else:
-            try:
-                return [m / UnitConverter._recognized_units[out_unit.lower()][1] for m in molar_values]
-            except KeyError:
-                raise ValueError(f'Unit {out_unit} not recognized.')
+            return [(m*mw) / UnitConverter._recognized_units[out_unit.lower()][1] for m, mw in zip(molar_values, mws)]
     
     @staticmethod
     def standardize_units(df, unit_col_name) -> pd.DataFrame:
@@ -161,9 +170,9 @@ class UnitConverter:
         Returns:
             Union[float]: Molar value. np.nan if the standard unit is not found in self.molar or self.g_ovr_l.
         """
-        if row[self._standard_unit_col] in self.molar:
+        if row[self._standard_unit_col] in UnitConverter._molars:
             molar_val = float(row[self._value_col])*row[self._multiplier_col]
-        elif row[self._standard_unit_col] in self.g_ovr_l:  # Divide by mw (g/mol) -> g/L * mol/g = M
+        elif row[self._standard_unit_col] in UnitConverter._g_ovr_ls:  # Divide by mw (g/mol) -> g/L * mol/g = M
             molar_val = float(row[self._value_col])*row[self._multiplier_col]/row[self._mw_col]  # Divide by mw
         else:
             molar_val = np.nan
