@@ -7,9 +7,9 @@ bleach_schema = Schema({
     'structure_type': Or('smiles', 'mol'),
 
     # Target data
-    'target_col': str,
-    'input_units': Or('mixed', '-log(M)', 'M', 'mM', 'µM', 'uM', 'nM'),
-    'output_units': Or('-log(M)', 'M', 'mM', 'µM', 'uM', 'nM'),
+    'target_col': Or(str, None),
+    'input_units': Or('mixed', '-log(M)', 'M', 'mM', 'µM', 'uM', 'nM', ''),
+    'output_units': Or('-log(M)', 'M', 'mM', 'µM', 'uM', 'nM', ''),
     'units_col': str,
     'drop_na_units': bool,
 
