@@ -8,6 +8,7 @@ from math import log10
 
 from naclo import binarize_default_params, binarize_default_options
 from naclo import Binarize
+import stse
 
 
 class TestBinarize(unittest.TestCase):
@@ -102,9 +103,6 @@ class TestBinarize(unittest.TestCase):
             binarize.convert_units('unknown')
         
     def test_binarize_no_qualifiers(self):
-        options = deepcopy(self.default_options)
-        options['qualifiers']['run'] = False
-        
         expected_arrs = {
             '>': [1, 0, 0, 1, 1],
             '<': [0, 1, 0, 0, 0],
@@ -113,22 +111,24 @@ class TestBinarize(unittest.TestCase):
         }
         
         # Loop through allowed operators
-        for options['active_operator'] in ['>', '<', '>=', '<=']:
-            binarize = Binarize(self.test_df, params=self.default_params, options=options)
-            out_df, out_arr = binarize.binarize(self.test_df['target'])
+        for op in ['>', '<', '>=', '<=']:
+            out_df, out_arr = Binarize.binarize(self.test_df, values=self.test_df['target'],
+                                                decision_boundary=int(self.default_params['decision_boundary']),
+                                                qualifier_col_name=None, active_operator=op)
 
             self.assertTrue(
-                out_df.equals(binarize.df)  # No qualifier drop bc no qualifiers
+                out_df.equals(self.test_df)  # No qualifier drop bc no qualifiers
             )
             
             self.assertTrue(
                 np.array_equal(
-                    list(expected_arrs[options['active_operator']]),
+                    list(expected_arrs[op]),
                     out_arr
                 )
             )
 
         # Unknown operator
+        options = deepcopy(self.default_options)
         options['active_operator'] = 'unknown'
         with self.assertRaises(ValueError):
             binarize = Binarize(self.test_df, params=self.default_params, options=options)
@@ -140,25 +140,28 @@ class TestBinarize(unittest.TestCase):
         options['qualifiers']['qualifier_col'] = 'qualifiers'
         
         expected_arrs = {
-            '>': [1, 0, 0],
-            '<': [0, 1, 0],
-            '>=': [1, 0, 1],
-            '<=': [0, 1, 1]
+            '>': [1, 0, 0, np.nan],
+            '<': [0, 1, 0, np.nan],
+            '>=': [1, 0, 1, np.nan],
+            '<=': [0, 1, 1, np.nan]
         }
         
+        test_df = stse.dataframes.convert_to_nan(self.test_df)
+        
         # Loop through allowed operators
-        for options['active_operator'] in ['>', '<', '>=', '<=']:
-            binarize = Binarize(self.test_df, params=self.default_params, options=options)
-            out_df, out_arr = (binarize.binarize(self.test_df['target'][:-1]))
+        for op in ['>', '<', '>=', '<=']:
+            out_df, out_arr = Binarize.binarize(test_df, values=test_df['target'],
+                                                decision_boundary=int(self.default_params['decision_boundary']),
+                                                qualifier_col_name='qualifiers', active_operator=op)
             
             self.assertTrue(
-                out_df.equals(binarize.df.dropna(subset=['qualifiers']))
+                out_df.equals(test_df.dropna(subset=['qualifiers']))
             )
-            
             self.assertTrue(
-                np.array_equal(
-                    list(expected_arrs[options['active_operator']]),
-                    out_arr
+                np.allclose(
+                    list(expected_arrs[op]),
+                    out_arr,
+                    equal_nan=True
                 )
             )
         
