@@ -110,10 +110,33 @@ class TestUnitConverter(unittest.TestCase):
         )
         
     def test_convert(self):
+        # Test molar values --> -log(M) w/ case insensitivity
         units = ['M', 'mM', 'uM', 'nM', 'µM']
         for unit in units + [u.lower() for u in units] + [u.upper() for u in units[:-1]]:  # DONT CAP THE MU
             out = UnitConverter.convert(self.test_values, unit, '-log(m)')
             self.assertIsInstance(out, list)
+            
+        # Test g/L values
+        g_ovr_l_units = ['g/l', 'mg/L', 'ug/L', 'ng/L']
+        g_ovr_l_test_values = [5]
+        test_mws = [100]
+        molars = [5/100, 5e-3/100, 5e-6/100, 5e-9/100]
+        
+        for u, m in zip(g_ovr_l_units, molars):
+            self.assertAlmostEqual(
+                UnitConverter.convert(g_ovr_l_test_values, u, 'm', test_mws)[0],
+                m
+            )
+        
+        # No change
+        self.assertEqual(
+            UnitConverter.convert(g_ovr_l_test_values, 'g/l', 'g/l', test_mws),
+            g_ovr_l_test_values
+        )
+        
+        # print(self.test_values)
+        # mws = []
+        # for unit in units + [u.lower() for u in units] + [u.upper() for u in units[:-1]]:
         
         # ERROR: invalid input unit
         with self.assertRaises(ValueError):
